
.. image:: pyrf_logo.png
   :alt: PyRF logo

PyRF Documentation
==================

Contents:

.. toctree::
   :maxdepth: 2

   usermanual
   reference
   examples
   plans


Hardware Support
----------------

This library currently supports development for the
`ThinkRF WSA4000 and WSA5000`_ platforms.

.. _ThinkRF WSA4000 and WSA5000: http://www.thinkrf.com/

Links
-----

* `Official github page <https://github.com/pyrf/pyrf>`_
* `Documentation for this API <http://www.pyrf.org>`_
* `WSA4000/WSA5000 Documentation <http://www.thinkrf.com/resources>`_

Spectrum Analyzer GUI
---------------------

.. image:: speca-gui.png
   :alt: speca-gui screen shot

.. image:: speca-gui-2.png
   :alt: speca-gui screen shot

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

